@@ -38,15 +38,6 @@ def update_w_custom(config, lane_info):
             config["resources"][prog][key] = val
     return config
 
-def add_cached_versions(config):
-    """Add version information to configuration, avoiding multiple access during parallel runs.
-    """
-    from bcbio import broad
-    # cache GATK version in sample information to avoid multiple retrievals later
-    if "gatk" in config["resources"]:
-        config["resources"]["gatk"]["version"] = broad.runner_from_config(config).get_gatk_version()
-    return config
-
 # ## Retrieval functions
 
 def load_system_config(config_file):
@@ -154,7 +145,7 @@ def _get_program_dir(name, config):
     elif isinstance(config, basestring):
         return config
     elif config.has_key("dir"):
-        return config["dir"]
+        return expand_path(config["dir"])
     else:
         raise ValueError("Could not find directory in config for %s" % name)
 
@@ -227,6 +218,8 @@ def use_vqsr(algs):
         callers = alg.get("variantcaller", "gatk")
         if isinstance(callers, basestring):
             callers = [callers]
+        elif not callers: # no variant calling, no VQSR
+            continue
         vqsr_supported_caller = False
         for c in callers:
             if c in ["gatk", "gatk-haplotype"]:
