@@ -14,34 +14,16 @@ from bcbio.bam.trim import brun_trim_fastq, trim_read_through
 from bcbio.pipeline.fastq import get_fastq_files, needs_fastq_conversion
 from bcbio.pipeline.alignment import align_to_sort_bam
 from bcbio.pipeline import cleanbam
-from bcbio.ngsalign.split import split_read_files
 from bcbio.variation import recalibrate, vcfutils
 
 def _item_needs_compute(lane_items):
     """Determine if any item needs computing resources to spin up a cluster.
     """
     for item in lane_items:
-        config = item["config"]
-        split_size = config.get("distributed", {}).get("align_split_size",
-                                                       config["algorithm"].get("align_split_size", None))
-        if split_size is not None:
-            return True
         if needs_fastq_conversion(item, item["config"]):
             return True
     return False
 
-def _prep_fastq_files(item, bc_files, dirs, config):
-    """Potentially prepare input FASTQ files for processing.
-    """
-    fastq1, fastq2 = bc_files[item["barcode_id"]]
-    split_size = config.get("distributed", {}).get("align_split_size",
-                                                   config["algorithm"].get("align_split_size", None))
-    if split_size:
-        split_dir = utils.safe_makedir(os.path.join(dirs["work"], "align_splitprep", item["description"]))
-        return split_read_files(fastq1, fastq2, item, split_size, split_dir, dirs, config)
-    else:
-        return [[fastq1, fastq2, None]]
-
 def process_all_lanes(lanes, run_parallel):
     """Process all input lanes, avoiding starting a cluster if not needed.
     """
@@ -142,11 +124,10 @@ def process_alignment(data):
         fastq1, fastq2 = data["files"][0], None
     config = data["config"]
     aligner = config["algorithm"].get("aligner", None)
-    out_bam = ""
-    if os.path.exists(fastq1) and aligner:
+    if fastq1 and os.path.exists(fastq1) and aligner:
         logger.info("Aligning lane %s with %s aligner" % (data["rgnames"]["lane"], aligner))
-        out_bam = align_to_sort_bam(fastq1, fastq2, aligner, data)
-    elif os.path.exists(fastq1) and fastq1.endswith(".bam"):
+        data = align_to_sort_bam(fastq1, fastq2, aligner, data)
+    elif fastq1 and os.path.exists(fastq1) and fastq1.endswith(".bam"):
         sort_method = config["algorithm"].get("bam_sort")
         bamclean = config["algorithm"].get("bam_clean")
         if sort_method:
@@ -160,20 +141,19 @@ def process_alignment(data):
             out_bam = link_bam_file(fastq1, os.path.join(data["dirs"]["work"], "prealign",
                                                          data["rgnames"]["sample"]))
         _check_prealigned_bam(fastq1, data["sam_ref"], config)
-    if not out_bam and not os.path.exists(fastq1):
-        raise ValueError("Could not find input file: %s" % fastq1)
-    data["work_bam"] = out_bam
-    return [[data]]
-
-def align_prep_full(data, config_file):
-    """Perform alignment and post-processing required on full BAM files.
-    Prepare list of callable genome regions allowing subsequent parallelization.
-    """
-    if data["files"][0] is None and "vrn_file" in data:
+        data["work_bam"] = out_bam
+    elif fastq1 is None and "vrn_file" in data:
         data["config"]["algorithm"]["variantcaller"] = ""
         data["work_bam"] = None
     else:
-        data = process_alignment(data)[0][0]
+        raise ValueError("Could not process input file: %s" % fastq1)
+    return [[data]]
+
+def postprocess_alignment(data):
+    """Perform post-processing steps required on full BAM files.
+    Prepares list of callable genome regions allowing subsequent parallelization.
+    """
+    if data["work_bam"]:
         callable_region_bed, nblock_bed = callable.block_regions(data["work_bam"],
                                                                  data["sam_ref"], data["config"])
         data["regions"] = {"nblock": nblock_bed}
