@@ -15,15 +15,55 @@ from bcbio.rnaseq import qc
 from bcbio.distributed.messaging import parallel_runner
 from bcbio.distributed.ipython import global_parallel
 from bcbio.log import logger
+from bcbio.ngsalign import alignprep
 from bcbio.pipeline import lane, region, run_info, qcsummary, version
+from bcbio.pipeline.config_utils import load_system_config
 from bcbio.provenance import programs, system, versioncheck
+from bcbio.server import main as server_main
 from bcbio.solexa.flowcell import get_fastq_dir
 from bcbio.variation.realign import parallel_realign_sample
 from bcbio.variation.genotype import parallel_variantcall, combine_multiple_callers
 from bcbio.variation import coverage, ensemble, population, recalibrate, validate
 
-def run_main(config, config_file, work_dir, parallel,
-         fc_dir=None, run_info_yaml=None):
+def run_main(work_dir, config_file=None, fc_dir=None, run_info_yaml=None,
+             numcores=None, paralleltype=None, queue=None, scheduler=None,
+             upgrade=None, profile=None, workflow=None, inputs=None,
+             resources="", timeout=15, retries=None):
+    """Run variant analysis, handling command line options.
+    """
+    config, config_file = load_system_config(config_file)
+    if config.get("log_dir", None) is None:
+        config["log_dir"] = os.path.join(work_dir, "log")
+    paralleltype, numcores = _get_cores_and_type(numcores, paralleltype, scheduler)
+    parallel = {"type": paralleltype, "cores": numcores,
+                "scheduler": scheduler, "queue": queue,
+                "profile": profile, "module": "bcbio.distributed",
+                "resources": resources, "timeout": timeout,
+                "retries": retries}
+    if parallel["type"] in ["local"]:
+        _run_toplevel(config, config_file, work_dir, parallel,
+                      fc_dir, run_info_yaml)
+    elif parallel["type"] == "ipython":
+        assert parallel["queue"] is not None, "IPython parallel requires a specified queue (-q)"
+        assert parallel["scheduler"] is not None, "IPython parallel requires a specified scheduler (-s)"
+        _run_toplevel(config, config_file, work_dir, parallel,
+                      fc_dir, run_info_yaml)
+    else:
+        raise ValueError("Unexpected type of parallel run: %s" % parallel["type"])
+
+def _get_cores_and_type(numcores, paralleltype, scheduler):
+    """Return core and parallelization approach from command line providing sane defaults.
+    """
+    if scheduler is not None:
+        paralleltype = "ipython"
+    if paralleltype is None:
+        paralleltype = "local"
+    if numcores is None:
+        numcores = 1
+    return paralleltype, int(numcores)
+
+def _run_toplevel(config, config_file, work_dir, parallel,
+                  fc_dir=None, run_info_yaml=None):
     """
     Run toplevel analysis, processing a set of input files.
     config_file -- Main YAML configuration file with system parameters
@@ -79,11 +119,15 @@ def parse_cl_args(in_args):
 
     Returns the main config file and set of kwargs.
     """
+    sub_cmds = {"upgrade": install.add_subparser,
+                "server": server_main.add_subparser}
     parser = argparse.ArgumentParser(
         description= "Best-practice pipelines for fully automated high throughput sequencing analysis.")
-    if len(in_args) > 0 and in_args[0] in ["upgrade"]:
+    sub_cmd = None
+    if len(in_args) > 0 and in_args[0] in sub_cmds:
         subparsers = parser.add_subparsers(help="bcbio-nextgen supplemental commands")
-        install.add_subparser(subparsers)
+        sub_cmds[in_args[0]](subparsers)
+        sub_cmd = in_args[0]
     else:
         parser.add_argument("global_config", help="Global YAML configuration file specifying details "
                             "about the system (optional, defaults to installed bcbio_system.yaml)",
@@ -95,14 +139,14 @@ def parse_cl_args(in_args):
                             nargs="*")
         parser.add_argument("-n", "--numcores", type=int, default=0)
         parser.add_argument("-t", "--paralleltype", help="Approach to parallelization",
-                            choices=["local", "ipython", "messaging"], default="local")
+                            choices=["local", "ipython"], default="local")
         parser.add_argument("-s", "--scheduler", help="Schedulerto use for ipython parallel",
                             choices=["lsf", "sge", "torque", "slurm"])
         parser.add_argument("-q", "--queue", help="Scheduler queue to run jobs on, for ipython parallel")
         parser.add_argument("-r", "--resources",
-                            help=("Cluster specific resources specifications. Provide multiple specs separated by ';'\n"
-                                  "Supports SGE: translated to -l parameters"),
-                            default="")
+                            help=("Cluster specific resources specifications. Can be specified multiple times.\n"
+                                  "Supports SGE and SLURM parameters."),
+                            default=[], action="append")
         parser.add_argument("--timeout", help="Number of minutes before cluster startup times out. Defaults to 15",
                             default=15, type=int)
         parser.add_argument("--retries",
@@ -111,8 +155,6 @@ def parse_cl_args(in_args):
                             default=0, type=int)
         parser.add_argument("-p", "--profile", help="Profile name to use for ipython parallel",
                             default="bcbio_nextgen")
-        parser.add_argument("-u", "--upgrade", help="Perform an upgrade of bcbio_nextgen in place.",
-                            choices = ["stable", "development", "system"])
         parser.add_argument("-w", "--workflow", help="Run a workflow with the given commandline arguments")
         parser.add_argument("-v", "--version", help="Print current version",
                             action="store_true")
@@ -126,13 +168,13 @@ def parse_cl_args(in_args):
                   "retries": args.retries,
                   "resources": args.resources,
                   "profile": args.profile,
-                  "upgrade": args.upgrade,
                   "workflow": args.workflow}
         kwargs = _add_inputs_to_kwargs(args, kwargs, parser)
     else:
+        assert sub_cmd is not None
         kwargs = {"args": args,
                   "config_file": None,
-                  "upgrade": args.upgrade}
+                  sub_cmd: True}
     return kwargs
 
 def _add_inputs_to_kwargs(args, kwargs, parser):
@@ -245,13 +287,17 @@ class Variant2Pipeline(AbstractPipeline):
     name = "variant2"
 
     @classmethod
-    def run(self, config, config_file, run_parallel, parallel, dirs, lane_items):
+    def run(self, config, config_file, run_parallel, parallel, dirs, samples):
         ## Alignment and preparation requiring the entire input file (multicore cluster)
-        with global_parallel(parallel, "multicore", ["align_prep_full"],
-                             lane_items, dirs, config) as parallel:
+        with global_parallel(parallel, "multicore", ["process_alignment", "postprocess_alignment"],
+                             samples, dirs, config,
+                             multiplier=alignprep.parallel_multiplier(samples)) as parallel:
             run_parallel = parallel_runner(parallel, dirs, config)
             logger.info("Timing: alignment")
-            samples = run_parallel("align_prep_full", [list(x) + [config_file] for x in lane_items])
+            samples = run_parallel("prep_align_inputs", samples)
+            samples = run_parallel("process_alignment", samples)
+            samples = alignprep.merge_split_alignments(samples, run_parallel)
+            samples = run_parallel("postprocess_alignment", samples)
             regions = callable.combine_sample_regions(samples)
             samples = region.add_region_info(samples, regions)
             samples = region.clean_sample_data(samples)
@@ -261,7 +307,7 @@ class Variant2Pipeline(AbstractPipeline):
         ## Variant calling on sub-regions of the input file (full cluster)
         with global_parallel(parallel, "full", ["piped_bamprep", "variantcall_sample"],
                              samples, dirs, config,
-                             multiplier=len(regions["analysis"])) as parallel:
+                             multiplier=len(regions["analysis"]), max_multicore=1) as parallel:
             run_parallel = parallel_runner(parallel, dirs, config)
             logger.info("Timing: alignment post-processing")
             samples = region.parallel_prep_region(samples, regions, run_parallel)
@@ -305,7 +351,7 @@ class StandardPipeline(AbstractPipeline):
     @classmethod
     def run(self, config, config_file, run_parallel, parallel, dirs, lane_items):
         ## Alignment and preparation requiring the entire input file (multicore cluster)
-        with global_parallel(parallel, "multicore", ["align_prep_full"],
+        with global_parallel(parallel, "multicore", ["process_alignment"],
                              lane_items, dirs, config) as parallel:
             run_parallel = parallel_runner(parallel, dirs, config)
             logger.info("Timing: alignment")
