@@ -9,7 +9,7 @@ from bcbio import utils
 from bcbio.log import logger, logger_cl
 from bcbio.provenance import diagnostics
 
-def run(cmd, descr, data=None, checks=None):
+def run(cmd, descr, data=None, checks=None, log_error=True):
     """Run the provided command, logging details and checking for errors.
     """
     if data:
@@ -22,7 +22,8 @@ def run(cmd, descr, data=None, checks=None):
         _do_run(cmd, checks)
     except:
         diagnostics.end_cmd(cmd_id, False)
-        logger.exception()
+        if log_error:
+            logger.exception()
         raise
     finally:
         diagnostics.end_cmd(cmd_id)
@@ -43,7 +44,8 @@ def _normalize_cmd_args(cmd):
     intermediate errors.
     """
     if isinstance(cmd, basestring):
-        if cmd.find(" | ") > 0:
+        # check for standard or anonymous named pipes
+        if cmd.find(" | ") > 0 or cmd.find(">(") or cmd.find("<("):
             return "set -o pipefail; " + cmd, True, _find_bash()
         else:
             return cmd, True, None
@@ -96,3 +98,23 @@ def file_exists(target_file):
             logger.info("Did not find output file {0}".format(target_file))
         return ok
     return check
+
+def file_reasonable_size(target_file, input_file):
+    def check():
+        # named pipes -- we can't calculate size
+        if input_file.strip().startswith("<("):
+            return True
+        if input_file.endswith((".bam", ".gz")):
+            scale = 5.0
+        else:
+            scale = 10.0
+        orig_size = os.path.getsize(input_file) / pow(1024.0, 3)
+        out_size = os.path.getsize(target_file) / pow(1024.0, 3)
+        if out_size < (orig_size / scale):
+            logger.info("Output file unexpectedly small. %.1fGb for output versus "
+                        "%.1fGb for the input file. This often indicates a truncated "
+                        "BAM file or memory errors during the run." % (out_size, orig_size))
+            return False
+        else:
+            return True
+    return check
