@@ -113,7 +113,7 @@ def _get_files_project(sample, upload_config):
     """Retrieve output files associated with an entire analysis project.
     """
     out = [{"path": sample["provenance"]["programs"]}]
-    if sample["summary"].get("project"):
+    if "summary" in sample and sample["summary"].get("project"):
         out.append({"path": sample["summary"]["project"]})
     for x in sample.get("variants", []):
         if "pop_db" in x:
