@@ -10,8 +10,10 @@ import os
 import yaml
 
 from bcbio import utils
+from bcbio.bam import callable
+from bcbio.pipeline import config_utils
 from bcbio.pipeline import genome
-from bcbio.variation import ensemble
+from bcbio.provenance import do
 
 # ## Individual sample comparisons
 
@@ -59,10 +61,23 @@ def compare_to_rm(data):
                "concordant": os.path.join(work_dir, "%s-ref-eval-concordance.vcf" % sample),
                "discordant": os.path.join(work_dir, "%s-eval-ref-discordance-annotate.vcf" % sample)}
         if not utils.file_exists(out["concordant"]) or not utils.file_exists(out["grading"]):
-            ensemble.bcbio_variation_comparison(val_config_file, base_dir, data)
+            bcbio_variation_comparison(val_config_file, base_dir, data)
         data["validate"] = out
     return [[data]]
 
+def bcbio_variation_comparison(config_file, base_dir, data):
+    """Run a variant comparison using the bcbio.variation toolkit, given an input configuration.
+    """
+    tmp_dir = utils.safe_makedir(os.path.join(base_dir, "tmp"))
+    bv_jar = config_utils.get_jar("bcbio.variation",
+                                  config_utils.get_program("bcbio_variation",
+                                                           data["config"], "dir"))
+    resources = config_utils.get_resources("bcbio_variation", data["config"])
+    jvm_opts = resources.get("jvm_opts", ["-Xms750m", "-Xmx2g"])
+    java_args = ["-Djava.io.tmpdir=%s" % tmp_dir]
+    cmd = ["java"] + jvm_opts + java_args + ["-jar", bv_jar, "variant-compare", config_file]
+    do.run(cmd, "Comparing variant calls using bcbio.variation", data)
+
 def _create_validate_config_file(vrn_file, rm_file, rm_interval_file, rm_genome,
                                  base_dir, data):
     config_dir = utils.safe_makedir(os.path.join(base_dir, "config"))
@@ -86,7 +101,7 @@ def _create_validate_config(vrn_file, rm_file, rm_interval_file, rm_genome,
     else:
         eval_genome = None
         rm_genome = data["sam_ref"]
-    ref_call = {"file": rm_file, "name": "ref", "type": "grading-ref",
+    ref_call = {"file": str(rm_file), "name": "ref", "type": "grading-ref",
                 "preclean": True, "prep": True, "remove-refcalls": True}
     if rm_interval_file:
         ref_call["intervals"] = rm_interval_file
@@ -101,12 +116,25 @@ def _create_validate_config(vrn_file, rm_file, rm_interval_file, rm_genome,
            "calls": [ref_call, eval_call]}
     if data.get("callable_bam"):
         exp["align"] = data["callable_bam"]
-    intervals = ensemble.get_analysis_intervals(data)
+    intervals = get_analysis_intervals(data)
     if intervals:
         exp["intervals"] = os.path.abspath(intervals)
     return {"dir": {"base": base_dir, "out": "work", "prep": "work/prep"},
             "experiments": [exp]}
 
+def get_analysis_intervals(data):
+    """Retrieve analysis regions for the current variant calling pipeline.
+    """
+    if data.get("ensemble_bed"):
+        return data["ensemble_bed"]
+    elif data.get("callable_bam"):
+        return callable.sample_callable_bed(data["callable_bam"], data["sam_ref"], data["config"])
+    else:
+        for key in ["callable_regions", "variant_regions"]:
+            intervals = data["config"]["algorithm"].get(key)
+            if intervals:
+                return intervals
+
 # ## Summarize comparisons
 
 def _flatten_grading(stats):
