@@ -3,7 +3,7 @@
 http://varscan.sourceforge.net/
 """
 import contextlib
-import itertools
+from distutils.version import LooseVersion
 import os
 import shutil
 
@@ -33,6 +33,7 @@ def run_varscan(align_bams, items, ref_file, assoc_files,
                                                 region, out_file)
     return call_file
 
+
 def _get_varscan_opts(config):
     """Retrieve common options for running VarScan.
     Handles jvm_opts, setting user and country to English to avoid issues
@@ -43,6 +44,7 @@ def _get_varscan_opts(config):
     jvm_opts += ["-Duser.language=en", "-Duser.country=US"]
     return " ".join(jvm_opts)
 
+
 def _varscan_paired(align_bams, ref_file, items, target_regions, out_file):
 
     """Run a paired VarScan analysis, also known as "somatic". """
@@ -51,9 +53,9 @@ def _varscan_paired(align_bams, ref_file, items, target_regions, out_file):
     config = items[0]["config"]
 
     version = programs.jar_versioner("varscan", "VarScan")(config)
-    if version < "v2.3.5":
+    if LooseVersion(version) < LooseVersion("v2.3.6"):
         raise IOError(
-            "Please install version 2.3.5 or better of VarScan with support "
+            "Please install version 2.3.6 or better of VarScan with support "
             "for multisample calling and indels in VCF format.")
     varscan_jar = config_utils.get_jar(
         "VarScan",
@@ -63,7 +65,8 @@ def _varscan_paired(align_bams, ref_file, items, target_regions, out_file):
 
     # No need for names in VarScan, hence the "_"
 
-    tumor_bam, _, normal_bam, _ = get_paired_bams(align_bams, items)
+    tumor_bam, tumor_name, normal_bam, normal_name = get_paired_bams(
+        align_bams, items)
 
     if not file_exists(out_file):
         base, ext = os.path.splitext(out_file)
@@ -110,11 +113,17 @@ def _varscan_paired(align_bams, ref_file, items, target_regions, out_file):
             do.run(varscan_cmd, "Varscan".format(**locals()), None,
                    None)
 
+        # VarScan files need to be corrected to match the VCF specification
+        # We do this before combining them otherwise merging may fail
+        # if there are invalid records
+
         if do.file_exists(snp_file):
             to_combine.append(snp_file)
+            _fix_varscan_vcf(snp_file, normal_name, tumor_name)
 
         if do.file_exists(indel_file):
             to_combine.append(indel_file)
+            _fix_varscan_vcf(indel_file, normal_name, tumor_name)
 
         if not to_combine:
             write_empty_vcf(out_file)
@@ -132,10 +141,8 @@ def _varscan_paired(align_bams, ref_file, items, target_regions, out_file):
         if os.path.getsize(out_file) == 0:
             write_empty_vcf(out_file)
 
-        _fix_varscan_vcf(out_file, align_bams)
 
-
-def _fix_varscan_vcf(orig_file, in_bams):
+def _fix_varscan_vcf(orig_file, normal_name, tumor_name):
     """Fixes issues with the standard VarScan VCF output.
 
     - Remap sample names back to those defined in the input BAM file.
@@ -151,26 +158,106 @@ def _fix_varscan_vcf(orig_file, in_bams):
                 with open(tx_out_file, "w") as out_handle:
 
                     for line in in_handle:
-                        if line.startswith("#CHROM"):
-                            line = _fix_sample_line(line, in_bams)
+                        line = _fix_varscan_output(line, normal_name,
+                                                   tumor_name)
+                        if not line:
+                            continue
                         out_handle.write(line)
 
-def _fix_sample_line(line, in_bams):
-    """Pull sample names from input BAMs and replace VCF file header.
+
+def _fix_varscan_output(line, normal_name, tumor_name):
+    """Fix a varscan VCF line
+
+    Fixes the ALT column and also fixes the FREQ field to be a floating point
+    value, easier for filtering.
+
+    :param line: a pre-split and stripped varscan line
+
+    This function was contributed by Sean Davis <sdavis2@mail.nih.gov>,
+    with minor modifications by Luca Beltrame <luca.beltrame@marionegri.it>.
+
     """
-    samples = []
-    for in_bam in in_bams:
-        with contextlib.closing(pysam.Samfile(in_bam, "rb")) as work_bam:
-            for rg in work_bam.header.get("RG", []):
-                samples.append(rg["SM"])
-    parts = line.split("\t")
-    standard = parts[:9]
-    old_samples = parts[9:]
-    if len(old_samples) == 0:
-        return line
+    line = line.strip()
+
+    if(line.startswith("##")):
+        line = line.replace('FREQ,Number=1,Type=String',
+                            'FREQ,Number=1,Type=Float')
+        return line + "\n"
+
+    line = line.split("\t")
+
+    mapping = {"NORMAL": normal_name, "TUMOR": tumor_name}
+
+    if(line[0].startswith("#CHROM")):
+
+        base_header = line[:9]
+        old_samples = line[9:]
+
+        if len(old_samples) == 0:
+            return "\t".join(line) + "\n"
+
+        samples = [mapping[sample_name] for sample_name in old_samples]
+
+        assert len(old_samples) == len(samples)
+        return "\t".join(base_header + samples) + "\n"
+
+    try:
+        REF, ALT = line[3:5]
+    except ValueError:
+        return "\t".join(line) + "\n"
+
+    Ifreq = line[8].split(":").index("FREQ")
+    ndat = line[9].split(":")
+    tdat = line[10].split(":")
+    somatic_status = line[7].split(";")  # SS=<number>
+    # HACK: The position of the SS= changes, so we just search for it
+    somatic_status = [item for item in somatic_status
+                      if item.startswith("SS=")][0]
+    somatic_status = int(somatic_status.split("=")[1])  # Get the number
+
+    ndat[Ifreq] = str(float(ndat[Ifreq].rstrip("%")) / 100)
+    tdat[Ifreq] = str(float(tdat[Ifreq].rstrip("%")) / 100)
+    line[9] = ":".join(ndat)
+    line[10] = ":".join(tdat)
+
+    #FIXME: VarScan also produces invalid REF records (e.g. CAA/A)
+    # This is not handled yet.
+
+    if somatic_status == 5:
+
+        # "Unknown" states are broken in current versions of VarScan
+        # so we just bail out here for now
+
+        return
+
+    if "+" in ALT or "-" in ALT:
+        if "/" not in ALT:
+            if ALT[0] == "+":
+                R = REF
+                A = REF + ALT[1:]
+            elif ALT[0] == "-":
+                R = REF + ALT[1:]
+                A = REF
+        else:
+            Ins = [p[1:] for p in ALT.split("/") if p[0] == "+"]
+            Del = [p[1:] for p in ALT.split("/") if p[0] == "-"]
+
+            if len(Del):
+                REF += sorted(Del, key=lambda x: len(x))[-1]
+
+            A = ",".join([REF[::-1].replace(p[::-1], "", 1)[::-1]
+                          for p in Del] + [REF + p for p in Ins])
+            R = REF
+
+        REF = R
+        ALT = A
     else:
-        assert len(old_samples) == len(samples), (old_samples, samples)
-        return "\t".join(standard + samples) + "\n"
+        ALT = ALT.replace('/', ',')
+
+    line[3] = REF
+    line[4] = ALT
+    return "\t".join(line) + "\n"
+
 
 def _create_sample_list(in_bams, vcf_file):
     """Pull sample names from input BAMs and create input sample list.
@@ -192,9 +279,10 @@ def _varscan_work(align_bams, ref_file, items, target_regions, out_file):
 
     max_read_depth = "1000"
     version = programs.jar_versioner("varscan", "VarScan")(config)
-    if version < "v2.3.5":
-        raise IOError("Please install version 2.3.5 or better of VarScan with support "
-                      "for multisample calling and indels in VCF format.")
+    if version < "v2.3.6":
+        raise IOError("Please install version 2.3.6 or better of VarScan"
+                      " with support for multisample calling and indels"
+                      " in VCF format.")
     varscan_jar = config_utils.get_jar("VarScan",
                                        config_utils.get_program("varscan", config, "dir"))
     jvm_opts = _get_varscan_opts(config)
@@ -216,4 +304,4 @@ def _varscan_work(align_bams, ref_file, items, target_regions, out_file):
     # VarScan can create completely empty files in regions without
     # variants, so we create a correctly formatted empty file
     if os.path.getsize(out_file) == 0:
-       write_empty_vcf(out_file)
+        write_empty_vcf(out_file)
